@@ -20,7 +20,7 @@
 //!
 //! ```toml
 //! [dependencies]
-//! librsvg = "2.59.2"
+//! librsvg = "2.60.0-beta.0"
 //! cairo-rs = "0.20"
 //! gio = "0.20"   # only if you need streams
 //! ```
@@ -193,6 +193,7 @@ mod structure;
 mod style;
 mod surface_utils;
 mod text;
+mod text2;
 mod transform;
 mod unit_interval;
 mod url_resolver;
